@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2003-2018  Craig Barratt
+#   Copyright (C) 2003-2019  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 4.2.1, released 7 May 2018.
+# Version 4.3.1, released 14 Jul 2019.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -213,7 +213,7 @@ sub HostLink
 {
     my($host) = @_;
     my($s);
-    if ( defined($Hosts->{$host}) || defined($Status{$host}) ) {
+    if ( defined($Hosts->{$host}) ) {
         $s = "<a href=\"$MyURL?host=${EscURI($host)}\">$host</a>";
     } else {
         $s = $host;
@@ -358,8 +358,11 @@ sub CheckPermission
     return 0 if ( $User eq "" && $Conf{CgiAdminUsers} ne "*"
 	       || $host ne "" && !defined($Hosts->{$host}) );
     if ( $Conf{CgiAdminUserGroup} ne "" ) {
-        my($n,$p,$gid,$mem) = getgrnam($Conf{CgiAdminUserGroup});
-        $Privileged ||= ($mem =~ /\b\Q$User\E\b/);
+        for ( split(/\s+/, $Conf{CgiAdminUserGroup}) ) {
+            my ($n, $p, $gid, $mem) = getgrnam($_);
+            $Privileged ||= ( $mem =~ /\b\Q$User\E\b/ );
+            last if ( $Privileged );
+        }
     }
     if ( $Conf{CgiAdminUsers} ne "" ) {
         $Privileged ||= ($Conf{CgiAdminUsers} =~ /\b\Q$User\E\b/);
